@@ -19,8 +19,8 @@ package main
 import (
 	"github.com/spf13/cobra"
 
-	capp "github.com/kubernetes-incubator/cluster-capacity/cmd/cluster-capacity/app"
-	gapp "github.com/kubernetes-incubator/cluster-capacity/cmd/genpod/app"
+	capp "sigs.k8s.io/cluster-capacity/cmd/cluster-capacity/app"
+	gapp "sigs.k8s.io/cluster-capacity/cmd/genpod/app"
 )
 
 // HyperCC represents a single binary that can run any cluster capacity commands.
